@@ -9,6 +9,10 @@
 #' vapour pressure (ea) and relative humidity (RH) are calculated and returned
 #' in the final data frame.
 #'
+#' Parallel processing can be enabled using \code{\link[future]{plan}} to set
+#' up a parallel backend of your choice, e.g.,
+#' \code{future::plan(multisession)}. See examples for more.
+#'
 #' @details
 #' Stations reporting a latitude of < -90 or > 90 or longitude of < -180 or >
 #' 180 are removed. Stations may be individually checked for number of
@@ -71,11 +75,30 @@
 #' @examples
 #' \donttest{
 #' # Download weather station for Toowoomba, Queensland for 2010
-#' t <- get_GSOD(years = 2010, station = "955510-99999")
+#' tbar <- get_GSOD(years = 2010, station = "955510-99999")
+#'
+#' tbar
+#'
+#' # Download data for Australia from 2010 to 2015
+#' AUS <- get_GSOD(years = 2010:2015, country = "Australia")
+#'
+#' AUS
+#'
+#' # Download agroclimatology data for 2015 using parallel processing
+#' future::plan(multisession)
+#' ag <- get_GSOD(years = 2015, agroclimatology = TRUE)
+#'
+#' ag
+#'
+#' # Download global data for 2010 to 2015 with a maximum allowed 5 missing days
+#' # of data using parallel processing
+#'
+#' future::plan(multisession)
+#' global <- get_GSOD(years = 2010:2015, max_missing = 5)
+#'
+#' global
 #'
-#' t
 #' }
-#'
 #' @author Adam H Sparks, \email{adamhsparks@@gmail.com}
 #'
 #' @references {Jarvis, A., Reuter, H. I, Nelson, A., Guevara, E. (2008)
@@ -89,7 +112,8 @@
 #' \code{\link{reformat_GSOD}}
 #'
 #' @importFrom magrittr %>%
-#' @export
+#' @export get_GSOD
+
 get_GSOD <- function(years,
                      station = NULL,
                      country = NULL,
@@ -121,7 +145,7 @@ get_GSOD <- function(years,
     }
   }
 
-  # CRAN NOTE avoidance
+# CRAN NOTE avoidance
   isd_history <- NULL # nocov
 
   # Load station list
@@ -136,15 +160,15 @@ get_GSOD <- function(years,
   )
 
   # Download files from server -----------------------------------------------
-  GSOD_list <- .download_files(ftp_base, station, years, cache_dir)
+  file_list <- .download_files(ftp_base, station, years, cache_dir)
 
-  # Subset GSOD_list for agroclimatology only stations -----------------------
+  # Subset file_list for agroclimatology only stations -----------------------
   if (isTRUE(agroclimatology)) {
-    GSOD_list <-
-      .agroclimatology_list(GSOD_list, isd_history, cache_dir, years)
+    file_list <-
+      .agroclimatology_list(file_list, isd_history, cache_dir, years)
   }
 
-  # Subset GSOD_list for specified country -------------------------------------
+  # Subset file_list for specified country -------------------------------------
   if (!is.null(country)) {
     # Load country list
     # CRAN NOTE avoidance
@@ -153,10 +177,10 @@ get_GSOD <- function(years,
 
     country <- .validate_country(country, country_list)
 
-    GSOD_list <-
+    file_list <-
       .subset_country_list(country,
                            country_list,
-                           GSOD_list,
+                           file_list,
                            isd_history,
                            cache_dir,
                            years)
@@ -164,16 +188,12 @@ get_GSOD <- function(years,
 
   # Validate stations for missing days -----------------------------------------
   if (!is.null(max_missing)) {
-    GSOD_list <-
-      .validate_missing_days(max_missing, GSOD_list)
+    file_list <-
+      .validate_missing_days(max_missing, file_list)
   }
 
-  # Clean and reformat list of station files from local disk in tempdir --------
-  GSOD_XY <- purrr::map(.x = GSOD_list,
-                        .f = .process_gz,
-                        isd_history = isd_history)  %>%
-    dplyr::bind_rows()
-
+  GSOD_XY <- apply_process_gz(file_list, isd_history)
+  return(GSOD_XY)
   # Cleanup --------------------------------------------------------------------
   files <-
     list.files(
@@ -186,6 +206,4 @@ get_GSOD <- function(years,
     )
   unlink(files, force = TRUE, recursive = TRUE)
   rm(cache_dir)
-  gc()
-  return(GSOD_XY)
 }
